# -*- coding: utf-8 -*-
"""
    __init__


    :copyright: (c) 2013-2014 by Openlabs Technologies & Consulting (P) Limited
    :license: BSD, see LICENSE for more details.
"""
from .test_user import suite  # noqa
